module TErrorGivenPartialSignature where

partial :: Int -> Int
partial x = init x
